"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.approveUseAuthority = exports.getApproveUseAuthorityInstructionDataSerializer = void 0;
const umi_1 = require("@metaplex-foundation/umi");
const accounts_1 = require("../accounts");
function getApproveUseAuthorityInstructionDataSerializer(context) {
    const s = context.serializer;
    return (0, umi_1.mapSerializer)(s.struct([
        ['discriminator', s.u8()],
        ['numberOfUses', s.u64()],
    ], { description: 'ApproveUseAuthorityInstructionData' }), (value) => ({ ...value, discriminator: 20 }));
}
exports.getApproveUseAuthorityInstructionDataSerializer = getApproveUseAuthorityInstructionDataSerializer;
function approveUseAuthority(context, input) {
    const signers = [];
    const keys = [];
    const programId = context.programs.getPublicKey('mplTokenMetadata', 'metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s');
    const useAuthorityRecordAccount = input.useAuthorityRecord;
    const ownerAccount = input.owner;
    const payerAccount = input.payer ?? context.payer;
    const userAccount = input.user;
    const ownerTokenAccountAccount = input.ownerTokenAccount;
    const mintAccount = input.mint;
    const metadataAccount = input.metadata ??
        (0, accounts_1.findMetadataPda)(context, { mint: (0, umi_1.publicKey)(mintAccount) });
    const burnerAccount = input.burner;
    const tokenProgramAccount = input.tokenProgram ?? {
        ...context.programs.getPublicKey('splToken', 'TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA'),
        isWritable: false,
    };
    const systemProgramAccount = input.systemProgram ?? {
        ...context.programs.getPublicKey('splSystem', '11111111111111111111111111111111'),
        isWritable: false,
    };
    const rentAccount = input.rent;
    keys.push({
        pubkey: useAuthorityRecordAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(useAuthorityRecordAccount, true),
    });
    signers.push(ownerAccount);
    keys.push({
        pubkey: ownerAccount.publicKey,
        isSigner: true,
        isWritable: (0, umi_1.checkForIsWritableOverride)(ownerAccount, true),
    });
    signers.push(payerAccount);
    keys.push({
        pubkey: payerAccount.publicKey,
        isSigner: true,
        isWritable: (0, umi_1.checkForIsWritableOverride)(payerAccount, true),
    });
    keys.push({
        pubkey: userAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(userAccount, false),
    });
    keys.push({
        pubkey: ownerTokenAccountAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(ownerTokenAccountAccount, true),
    });
    keys.push({
        pubkey: metadataAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(metadataAccount, false),
    });
    keys.push({
        pubkey: mintAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(mintAccount, false),
    });
    keys.push({
        pubkey: burnerAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(burnerAccount, false),
    });
    keys.push({
        pubkey: tokenProgramAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(tokenProgramAccount, false),
    });
    keys.push({
        pubkey: systemProgramAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(systemProgramAccount, false),
    });
    if (rentAccount) {
        keys.push({
            pubkey: rentAccount,
            isSigner: false,
            isWritable: (0, umi_1.checkForIsWritableOverride)(rentAccount, false),
        });
    }
    const data = getApproveUseAuthorityInstructionDataSerializer(context).serialize(input);
    const bytesCreatedOnChain = 0;
    return (0, umi_1.transactionBuilder)([
        { instruction: { keys, programId, data }, signers, bytesCreatedOnChain },
    ]);
}
exports.approveUseAuthority = approveUseAuthority;
//# sourceMappingURL=approveUseAuthority.js.map