"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.revokeLockedTransferV1 = exports.getRevokeLockedTransferV1InstructionDataSerializer = void 0;
const umi_1 = require("@metaplex-foundation/umi");
const accounts_1 = require("../accounts");
function getRevokeLockedTransferV1InstructionDataSerializer(context) {
    const s = context.serializer;
    return (0, umi_1.mapSerializer)(s.struct([
        ['discriminator', s.u8()],
        ['revokeLockedTransferV1Discriminator', s.u8()],
    ], { description: 'RevokeLockedTransferV1InstructionData' }), (value) => ({
        ...value,
        discriminator: 45,
        revokeLockedTransferV1Discriminator: 7,
    }));
}
exports.getRevokeLockedTransferV1InstructionDataSerializer = getRevokeLockedTransferV1InstructionDataSerializer;
function revokeLockedTransferV1(context, input) {
    const signers = [];
    const keys = [];
    const programId = context.programs.getPublicKey('mplTokenMetadata', 'metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s');
    const delegateRecordAccount = input.delegateRecord ?? {
        ...programId,
        isWritable: false,
    };
    const delegateAccount = input.delegate;
    const mintAccount = input.mint;
    const metadataAccount = input.metadata ??
        (0, accounts_1.findMetadataPda)(context, { mint: (0, umi_1.publicKey)(mintAccount) });
    const masterEditionAccount = input.masterEdition ?? {
        ...programId,
        isWritable: false,
    };
    const tokenRecordAccount = input.tokenRecord ?? {
        ...programId,
        isWritable: false,
    };
    const tokenAccount = input.token ?? { ...programId, isWritable: false };
    const authorityAccount = input.authority ?? context.identity;
    const payerAccount = input.payer ?? context.payer;
    const systemProgramAccount = input.systemProgram ?? {
        ...context.programs.getPublicKey('splSystem', '11111111111111111111111111111111'),
        isWritable: false,
    };
    const sysvarInstructionsAccount = input.sysvarInstructions ??
        (0, umi_1.publicKey)('Sysvar1nstructions1111111111111111111111111');
    const splTokenProgramAccount = input.splTokenProgram ?? {
        ...programId,
        isWritable: false,
    };
    const authorizationRulesProgramAccount = input.authorizationRulesProgram ?? {
        ...programId,
        isWritable: false,
    };
    const authorizationRulesAccount = input.authorizationRules ?? {
        ...programId,
        isWritable: false,
    };
    keys.push({
        pubkey: delegateRecordAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(delegateRecordAccount, true),
    });
    keys.push({
        pubkey: delegateAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(delegateAccount, false),
    });
    keys.push({
        pubkey: metadataAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(metadataAccount, true),
    });
    keys.push({
        pubkey: masterEditionAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(masterEditionAccount, false),
    });
    keys.push({
        pubkey: tokenRecordAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(tokenRecordAccount, true),
    });
    keys.push({
        pubkey: mintAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(mintAccount, false),
    });
    keys.push({
        pubkey: tokenAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(tokenAccount, true),
    });
    signers.push(authorityAccount);
    keys.push({
        pubkey: authorityAccount.publicKey,
        isSigner: true,
        isWritable: (0, umi_1.checkForIsWritableOverride)(authorityAccount, false),
    });
    signers.push(payerAccount);
    keys.push({
        pubkey: payerAccount.publicKey,
        isSigner: true,
        isWritable: (0, umi_1.checkForIsWritableOverride)(payerAccount, true),
    });
    keys.push({
        pubkey: systemProgramAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(systemProgramAccount, false),
    });
    keys.push({
        pubkey: sysvarInstructionsAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(sysvarInstructionsAccount, false),
    });
    keys.push({
        pubkey: splTokenProgramAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(splTokenProgramAccount, false),
    });
    keys.push({
        pubkey: authorizationRulesProgramAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(authorizationRulesProgramAccount, false),
    });
    keys.push({
        pubkey: authorizationRulesAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(authorizationRulesAccount, false),
    });
    const data = getRevokeLockedTransferV1InstructionDataSerializer(context).serialize({});
    const bytesCreatedOnChain = 0;
    return (0, umi_1.transactionBuilder)([
        { instruction: { keys, programId, data }, signers, bytesCreatedOnChain },
    ]);
}
exports.revokeLockedTransferV1 = revokeLockedTransferV1;
//# sourceMappingURL=revokeLockedTransferV1.js.map