"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.utilize = exports.getUtilizeInstructionDataSerializer = void 0;
const umi_1 = require("@metaplex-foundation/umi");
const accounts_1 = require("../accounts");
function getUtilizeInstructionDataSerializer(context) {
    const s = context.serializer;
    return (0, umi_1.mapSerializer)(s.struct([
        ['discriminator', s.u8()],
        ['numberOfUses', s.u64()],
    ], { description: 'UtilizeInstructionData' }), (value) => ({ ...value, discriminator: 19 }));
}
exports.getUtilizeInstructionDataSerializer = getUtilizeInstructionDataSerializer;
function utilize(context, input) {
    const signers = [];
    const keys = [];
    const programId = context.programs.getPublicKey('mplTokenMetadata', 'metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s');
    const mintAccount = input.mint;
    const metadataAccount = input.metadata ??
        (0, accounts_1.findMetadataPda)(context, { mint: (0, umi_1.publicKey)(mintAccount) });
    const tokenAccountAccount = input.tokenAccount;
    const useAuthorityAccount = input.useAuthority;
    const ownerAccount = input.owner;
    const tokenProgramAccount = input.tokenProgram ?? {
        ...context.programs.getPublicKey('splToken', 'TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA'),
        isWritable: false,
    };
    const ataProgramAccount = input.ataProgram ?? {
        ...context.programs.getPublicKey('splAssociatedToken', 'ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL'),
        isWritable: false,
    };
    const systemProgramAccount = input.systemProgram ?? {
        ...context.programs.getPublicKey('splSystem', '11111111111111111111111111111111'),
        isWritable: false,
    };
    const rentAccount = input.rent ?? (0, umi_1.publicKey)('SysvarRent111111111111111111111111111111111');
    const useAuthorityRecordAccount = input.useAuthorityRecord;
    const burnerAccount = input.burner;
    keys.push({
        pubkey: metadataAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(metadataAccount, true),
    });
    keys.push({
        pubkey: tokenAccountAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(tokenAccountAccount, true),
    });
    keys.push({
        pubkey: mintAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(mintAccount, true),
    });
    signers.push(useAuthorityAccount);
    keys.push({
        pubkey: useAuthorityAccount.publicKey,
        isSigner: true,
        isWritable: (0, umi_1.checkForIsWritableOverride)(useAuthorityAccount, true),
    });
    keys.push({
        pubkey: ownerAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(ownerAccount, false),
    });
    keys.push({
        pubkey: tokenProgramAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(tokenProgramAccount, false),
    });
    keys.push({
        pubkey: ataProgramAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(ataProgramAccount, false),
    });
    keys.push({
        pubkey: systemProgramAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(systemProgramAccount, false),
    });
    keys.push({
        pubkey: rentAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(rentAccount, false),
    });
    if (useAuthorityRecordAccount) {
        keys.push({
            pubkey: useAuthorityRecordAccount,
            isSigner: false,
            isWritable: (0, umi_1.checkForIsWritableOverride)(useAuthorityRecordAccount, true),
        });
    }
    if (burnerAccount) {
        keys.push({
            pubkey: burnerAccount,
            isSigner: false,
            isWritable: (0, umi_1.checkForIsWritableOverride)(burnerAccount, false),
        });
    }
    const data = getUtilizeInstructionDataSerializer(context).serialize(input);
    const bytesCreatedOnChain = 0;
    return (0, umi_1.transactionBuilder)([
        { instruction: { keys, programId, data }, signers, bytesCreatedOnChain },
    ]);
}
exports.utilize = utilize;
//# sourceMappingURL=utilize.js.map